@@ -1,5 +1,4 @@
-`divvy.BPs` <-
-function(bp.polys, other.polys){
+divvy.BPs <- function(bp.polys, other.polys){
 	map <- t(sapply(bp.polys, function(x){
 		bp.area <- area.poly(x)
 		sapply(other.polys, function(y){
@@ -8,5 +7,4 @@ function(bp.polys, other.polys){
 	}))
 	if(length(other.polys)==1) map <- matrix(map,ncol=1)
 	return(map)
-}
-
+}
\ No newline at end of file
